==> tine20-inventory_2019.12.5.tar.bz2: Inventory/js/Inventory-lang-en_AU-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: en_AU\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Inventory item, Inventory items"
: [
  "Inventory item"
 ,"Inventory items"

]
, "Inventory item list, Inventory item lists"
: [
  ""
 ,""

]
, "Name"
: "Name"

, "Status"
: ""

, "Inventory ID"
: "Inventory ID"

, "Description"
: "Description"

, "Location"
: "Location"

, "Invoice date"
: ""

, "Invoice"
: "Invoice"

, "Price"
: "Price"

, "Cost Center"
: ""

, "Warranty"
: "Warranty"

, "Item added"
: "Item added"

, "Item removed"
: "Item removed"

, "Deprecate"
: ""

, "The active number must be less than or equal total number."
: "The active number must be less than or equal to the total number."

, "General"
: "General"

, "ID"
: "ID"

, "Enter description"
: "Enter description"

, "Added"
: "Added"

, "Removed"
: ""

, "Total number"
: "Total number"

, "Available number"
: ""

, "Accounting"
: "Accounting"

, "Cost center"
: ""

, "Depreciate"
: ""

, "Default Inventory Item Container"
: "Default Inventory Container"

, "The default container for new items"
: "The default container for new items"

, "Inventory Status Available"
: ""

, "Possible status."
: ""

, "ordered"
: ""

, "available"
: ""

, "defect"
: ""

, "missing"
: ""

, "removed"
: ""

, "unknown"
: ""

, "Inventory CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "All Inventory Items"
: ""

, "All existing Inventory Items"
: ""

, "Inventory"
: "Inventory"

, "Inventory item"
: "Inventory item"

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-inventory_2020.08.8.tar.bz2: Inventory/js/Inventory-lang-en_AU-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Inventory **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Inventory'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-13 11:05+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: English (Australia) (http://www.transifex.com/tine20/tine20/language/en_AU/)\nLanguage: en_AU\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Inventory Item Container"
: "Default Inventory Container"

, "The default container for new items"
: "The default container for new items"

, "The active number must be less than or equal total number."
: "The active number must be less than or equal to the total number."

, "General"
: "General"

, "ID"
: "ID"

, "Name"
: "Name"

, "Description"
: "Description"

, "Enter description"
: "Enter description"

, "Location"
: "Location"

, "Added"
: "Added"

, "Warranty"
: "Warranty"

, "Removed"
: ""

, "Total number"
: "Total number"

, "Available number"
: ""

, "Status"
: ""

, "Accounting"
: "Accounting"

, "Price"
: "Price"

, "Cost center"
: ""

, "Invoice"
: "Invoice"

, "Invoice date"
: ""

, "Depreciate"
: ""

, "All Inventory Items"
: ""

, "All existing Inventory Items"
: ""

, "Inventory"
: "Inventory"

, "Inventory Status Available"
: ""

, "Possible status."
: ""

, "ordered"
: ""

, "available"
: ""

, "defect"
: ""

, "missing"
: ""

, "removed"
: ""

, "unknown"
: ""

, "Inventory item, Inventory items"
: [
  "Inventory item"
 ,"Inventory items"

]
, "Inventory item list, Inventory item lists"
: [
  ""
 ,""

]
, "Inventory ID"
: "Inventory ID"

, "Cost Center"
: ""

, "Item added"
: "Item added"

, "Item removed"
: "Item removed"

, "Inventory CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Items imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Inventory item"
: "Inventory item"

, "Inventory item list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
